@@ -259,7 +259,7 @@ enum OER_TIMED_PRIORITIES {
 #define OER_NICKS_PER_KICK 1
 #define OER_MAXTARGETS 20
 #define OER_TARGET_DELAY 120
-#define OER_WALL_DELAY 5
+#define OER_WALL_DELAY 2
 #define OER_DEFAULT_DELIM "::"
 #define OER_DEFAULT_DELIM_LEN 2
 #define OER_QUOTE_MIN_LENGTH 10
@@ -320,16 +320,22 @@ enum OER_TIMED_PRIORITIES {
 #define STRINGLEN 128
 #define BIGSTRINGLEN 256
 #define HUGESTRINGLEN (WRITE_BUFFER_LENGTH - WRITE_BUFFER_HEADER_LENGTH)
-#define NICKLEN 32
-#define USERLEN 32
-#define CHANLEN 64
+/* YMMV depending on network/etc. */
+#define CHANLEN 50
 #define FLAGLEN 64
-#define HOSTLEN 256
+/* YMMV depending on network/etc. */
+#define HOSTLEN 63
+#define USERLEN 16
+/* YMMV depending on network/etc. */
+#define NICKLEN 15
+#define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
 #define OER_MAX_LIST_LINES 5
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
+#define DBSTATUS_MSG "At least one of the executed database queries failed, more \
+details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-19, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-20, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -367,7 +373,7 @@ struct locked {
 	int auto_unlock;
 	char reason[STRINGLEN + 1];
 	char nick[NICKLEN + 1];
-	char host[HOSTLEN + 1];
+	char host[USERHOSTLEN + 1];
 };
 
 struct chanuser {
@@ -526,7 +532,7 @@ struct state {
 	char flags[FLAGLEN + 1];
 	char ident[STRINGLEN + 1];
 	char usersfrom[STRINGLEN + 1];
-	char prefix[STRINGLEN + 1];
+	char prefix[TINYSTRINGLEN + 1];
 	char state[STRINGLEN + 1];
 	int customuser;
 	int vhost;
