@@ -48,31 +48,36 @@ static void handlesignal(int);
 int main(int argc, char *argv[])
 {
 	extern char *optarg;
-        
         extern int optind;
         extern int opterr;
         extern int optopt;
-
 #ifdef HAVE_LOCALE_H
         char *locptr;
 #endif
 	char config[TINYSTRINGLEN + 1];
+        char usersfrom[STRINGLEN + 1];
+        char state[STRINGLEN + 1];
 	int retval;
 	int c;
 	int do_help;
 	int do_version;
+	int do_usersfrom;
+	int do_state;
 	fd_set rsock;
 	pid_t newpid;
 	struct timeval tv;
 
+	/* set initial settings that affect ex. oer_debug() */
 	do_console = 0;
 	do_debug = OER_DEBUG_INFO;
 	do_help = 0;
 	do_signals = 1;
 	do_version = 0;
 	do_tempoutput = 1;
+	do_usersfrom = 0;
+	do_state = 0;
 	strncpy(config, "oer+MySQL.conf", TINYSTRINGLEN);
-        while((c = getopt(argc, argv, "cd:f:hsv")) > 0) {
+        while((c = getopt(argc, argv, "cd:f:hsu:t:v")) > 0) {
 		switch(c) {
 		case 'c':
 			do_console = 1;
@@ -89,6 +94,16 @@ int main(int argc, char *argv[])
 		case 's':
 			do_signals = 0;
 			break;
+		case 'u':
+			strncpy(usersfrom, optarg, STRINGLEN);
+			oer_debug(OER_DEBUG_INFO, "main->I will get my users with ident %s\n", usersfrom);
+			do_usersfrom = 1;
+			break;
+		case 't':
+			strncpy(state, optarg, STRINGLEN);
+			oer_debug(OER_DEBUG_INFO, "main->my state is %s\n", state);
+			do_state = 1;
+			break;
 		case 'v':
 			do_version = 1;
 			break;
@@ -97,7 +112,7 @@ int main(int argc, char *argv[])
 		}
 	}
 	if(do_help) {
-		oer_debug(OER_DEBUG_INFO, "usage: %s [-c] [-d <level>] [-f <config>] [-h] [-s] [-v]\n", argv[0]);
+		oer_debug(OER_DEBUG_INFO, "usage: %s [-c] [-d <level>] [-f <config>] [-h] [-s] [-u <ident>] [-t <state>] [-v]\n", argv[0]);
 		exit(EXIT_SUCCESS);
 	}
 	oer_debug(OER_DEBUG_INFO, "%s\n\n", OER_COPYRIGHT1);
@@ -127,7 +142,13 @@ int main(int argc, char *argv[])
 		oer_debug(OER_DEBUG_FATAL, "main->failed to allocate memory for irc state\n");
 		exit(EXIT_FAILURE);
 	}
-	strncpy(mystate->config, config, TINYSTRINGLEN);
+	strcpy(mystate->config, config);
+	if(do_usersfrom) {
+		strcpy(mystate->usersfrom, usersfrom);
+	}
+	if(do_state) {
+		strcpy(mystate->state, state);
+	}
 	if(!loadconf(mystate->config)) {
                 oer_debug(OER_DEBUG_FATAL, "main->loadconf() failed\n");
 		exit(EXIT_FAILURE);
@@ -171,34 +192,53 @@ int main(int argc, char *argv[])
 	do_tempoutput = 0;
 	mystate->loopforever = 1;
 	while(mystate->loopforever) {
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_FLOOD, "main->mainloop\n");
+#endif
 		mystate->now = time(NULL);
 		switch(serverconnection()) {
 		case OER_SERVERCONNECTION_ERR_SOCKET:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_FATAL, "main->socket() failed, exiting.\n");
+#endif
 			exit(EXIT_FAILURE);
 		case OER_SERVERCONNECTION_ERR_GETHOSTNAME:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_FATAL, "main->gethostname() failed, exiting.\n");
+#endif
 			exit(EXIT_FAILURE);
 		case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "main->gethostbyname() temporary error, retrying.\n");
+#endif
 			sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
 			break;
 		case OER_SERVERCONNECTION_ERR_GETSERVER_RETRY:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "main->getserver() temporary error, retrying.\n");
+#endif
 			sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
 			break;
 		case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_FATAL, "main->gethostbyname() fatal error, exiting.\n");
+#endif
 			exit(EXIT_FAILURE);
 		case OER_SERVERCONNECTION_ERR_BIND:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_FATAL, "main->bind() fatal error, exiting.\n");
+#endif
 			exit(EXIT_FAILURE);
 		case OER_SERVERCONNECTION_ERR_CONNECT_RETRY:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "main->connect() temporary error, retrying.\n");
+#endif
 			sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
 			break;
 		case OER_SERVERCONNECTION_ERR_CONNECT:
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_FATAL, "main->connect() fatal error, exiting.\n");
+#endif
 			exit(EXIT_FAILURE);
 		case OER_SERVERCONNECTION_ALREADY_CONNECTED:
 		case OER_SERVERCONNECTION_EVERYTHING_OK:
@@ -214,7 +254,9 @@ int main(int argc, char *argv[])
 		tv.tv_usec = OER_MAINLOOP_TIMEOUT_USECS;
 		retval = select(mystate->sockfd + 1, &rsock, NULL, NULL, &tv);
 		if(retval < 0) {
-			oer_debug(OER_DEBUG_INFO, "main->select() failed: %s\n", strerror(errno));
+#ifdef DEBUG
+			oer_debug(OER_DEBUG_ERROR, "main->select() failed: %s\n", strerror(errno));
+#endif
 			if(errno != EINTR) {
 				mystate->reconnect = OER_RECONNECT_ERROR;
 				reconnect();
@@ -269,6 +311,9 @@ int main(int argc, char *argv[])
 
 static void handlesignal(int signal)
 {
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_FLOOD, "handlesignal(%d)\n", signal);
+#endif
 	if(signal == SIGINT || signal == SIGTERM) {
 		if(do_signals) {
 			snprintf(mystate->signoff, STRINGLEN, "received %s, leaving for now but I will return!", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
@@ -276,7 +321,9 @@ static void handlesignal(int signal)
 			return;
 			
 		} else {
+#ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "handlesignal->%s received, ignoring (do_signals = 0)\n", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
+#endif
 		}
 	}
 	if(signal == SIGPIPE) {
