@@ -52,9 +52,9 @@ void parseirc(char *serveroutput)
 	char outstring3[WRITE_BUFFER_LENGTH + 1];
 	char channel[CHANLEN + 1];
 	char mode[CHANLEN + 1];
-	char user[HOSTLEN + 1];
-	char host[HOSTLEN + 1];
-	char userhost[HOSTLEN + 1];
+	char user[USERHOSTLEN + 1];
+	char host[USERHOSTLEN + 1];
+	char userhost[USERHOSTLEN + 1];
 	char nick[NICKLEN + 1];
 	char nick2[NICKLEN + 1];
 	char target[NICKLEN + 1];
@@ -438,14 +438,14 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
                 if(isme(nick)) {
                         /* strip user & host */
-                        strncpy(user, prefix + 1 + tpos, HOSTLEN);
+                        strncpy(user, prefix + 1 + tpos, USERHOSTLEN);
                         ptr = index(user, '@');
-                        memset(ptr, 0, HOSTLEN - strlen(user) + 1);
+                        memset(ptr, 0, USERHOSTLEN - strlen(user) + 1);
                         ptr = index(prefix + 1 + tpos, '@');
-                        strncpy(host, ptr + 1, HOSTLEN);
+                        strncpy(host, ptr + 1, USERHOSTLEN);
                         /* check if the server agrees with our perception
                            of our host */
                         if(strcasecmp(mystate->host, host)) {
@@ -545,7 +545,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 		strncpy(channel, params, CHANLEN);
 		/* the message starts at pos + 1 ... */
 		parsemsg(nick, userhost, channel, restptr + 1);
@@ -556,7 +556,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 		/* quit doesn't provide the channel, we have to check all channels */
 		for(this = mystate->channels; this != NULL; this = this->next) {
 			if(!isonchan(this, nick)) {
@@ -584,7 +584,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 		strncpy(channel, params, CHANLEN);
 		if((this = getchptr(channel)) == NULL) {
 			return;
@@ -617,7 +617,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "nickchange->%s is now known as %s, changing on all channels\n", nick, params + 1);
 #endif
@@ -656,7 +656,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 		strncpy(channel, params, CHANLEN);
 		if((this = getchptr(channel)) == NULL) {
 			return;
@@ -705,7 +705,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 		strncpy(channel, params, CHANLEN);
 		restpos = 0;
 		if((restpos = parse(restptr, restpos, " ", mode, CHANLEN, 0)) < 0) {
@@ -855,7 +855,7 @@ void parseirc(char *serveroutput)
 		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
-		strncpy(userhost, prefix + 1 + tpos, HOSTLEN);
+		strncpy(userhost, prefix + 1 + tpos, USERHOSTLEN);
 		restpos = 0;
 		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
@@ -1489,11 +1489,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(!isopnow(this, p1)) {
-				if(haschanflags(this, "u") && !isallowedop(this, p1)) {
-					continue;
-				}
-                                mmode_new(this, mystate->now, "+o", p1);
+			if(isopnow(this, p1)) {
+				continue;
+			}
+			if(haschanflags(this, "u") && isallowedop(this, p1)) {
+				mmode_new(this, mystate->now, "+o", p1);
 			}
 		}
 		return;
@@ -1842,11 +1842,6 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(!isopa(userhost)) {
-			if(hasuserflags(this, userhost, "d") == NULL) {
-				return;
-			}
-		}
 		if(!strlen(restptr)) {
 			return;
 		}
@@ -1859,11 +1854,6 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(!isopa(userhost)) {
-			if(hasuserflags(this, userhost, "d") == NULL) {
-				return;
-			}
-		}
 		if(!strlen(restptr)) {
 			return;
 		}
