@@ -9,9 +9,9 @@
 #
 
 CREATE TABLE seen_yourchannel (
-  twhen int(10) unsigned NOT NULL default '0',
-  nick varchar(32) NOT NULL default '',
-  hostmask varchar(64) NOT NULL default '',
-  KEY key1(nick)
-) TYPE=MyISAM;
+  twhen INT UNSIGNED NOT NULL,
+  nick CHAR(15) NOT NULL,
+  hostmask CHAR(80) NOT NULL,
+  INDEX (nick)
+) TYPE=MyISAM PACK_KEYS=1;
 
